Package com.pengrad.telegrambot.request
Class EditChatSubscriptionInviteLink
java.lang.Object
com.pengrad.telegrambot.request.BaseRequest<EditChatSubscriptionInviteLink,ChatInviteLinkResponse>
com.pengrad.telegrambot.request.EditChatSubscriptionInviteLink
public class EditChatSubscriptionInviteLink extends BaseRequest<EditChatSubscriptionInviteLink,ChatInviteLinkResponse>
Stas Parshin
10 March 2021
-
Field Summary
-
Constructor Summary
Constructors Constructor Description EditChatSubscriptionInviteLink(java.lang.Object chatId, java.lang.String inviteLink)Edit a subscription invite link created by the bot -
Method Summary
Modifier and Type Method Description EditChatSubscriptionInviteLinkname(java.lang.String name)Methods inherited from class com.pengrad.telegrambot.request.BaseRequest
add, addAll, getContentType, getFileName, getMethod, getParameters, getResponseType, getTimeoutSeconds, isMultipart, toWebhookResponse
-
Constructor Details
-
EditChatSubscriptionInviteLink
public EditChatSubscriptionInviteLink(java.lang.Object chatId, java.lang.String inviteLink)Edit a subscription invite link created by the bot- Parameters:
chatId- Unique identifier for the target chat or username of the target channel (in the format @channelusername)inviteLink- The invite link to edit
-
-
Method Details
-
name
- Parameters:
name- Invite link name; 0-32 characters- Returns:
-