Package com.pengrad.telegrambot.request
Class CreateChatSubscriptionInviteLink
java.lang.Object
com.pengrad.telegrambot.request.BaseRequest<CreateChatSubscriptionInviteLink,ChatInviteLinkResponse>
com.pengrad.telegrambot.request.CreateChatSubscriptionInviteLink
public class CreateChatSubscriptionInviteLink extends BaseRequest<CreateChatSubscriptionInviteLink,ChatInviteLinkResponse>
Stas Parshin
10 March 2021
-
Field Summary
-
Constructor Summary
Constructors Constructor Description CreateChatSubscriptionInviteLink(java.lang.Object chatId, java.lang.Integer subscriptionPeriod, java.lang.Integer subscriptionPrice)Create a subscription invite link for a channel chat. -
Method Summary
Modifier and Type Method Description CreateChatSubscriptionInviteLinkname(java.lang.String name)Methods inherited from class com.pengrad.telegrambot.request.BaseRequest
add, addAll, getContentType, getFileName, getMethod, getParameters, getResponseType, getTimeoutSeconds, isMultipart, toWebhookResponse
-
Constructor Details
-
CreateChatSubscriptionInviteLink
public CreateChatSubscriptionInviteLink(java.lang.Object chatId, java.lang.Integer subscriptionPeriod, java.lang.Integer subscriptionPrice)Create a subscription invite link for a channel chat.- Parameters:
chatId- Unique identifier for the target channel chat or username of the target channel (in the format @channelusername)subscriptionPeriod- The number of seconds the subscription will be active for before the next payment. Currently, it must always be 2592000 (30 days).subscriptionPrice- The amount of Telegram Stars a user must pay initially and after each subsequent subscription period to be a member of the chat; 1-2500
-
-
Method Details
-
name
- Parameters:
name- Invite link name; 0-32 characters
-